@@ -9,7 +9,7 @@ import javax.servlet.http.HttpServletRequest;
 
 import org.gcube.common.portal.mailing.EmailNotification;
 import org.gcube.datacatalogue.ckanutillibrary.server.DataCatalogue;
-import org.gcube.datacatalogue.ckanutillibrary.server.utils.UtilMethods;
+import org.gcube.datacatalogue.ckanutillibrary.server.utils.CatalogueUtilMethods;
 import org.gcube.datacatalogue.ckanutillibrary.shared.RolesCkanGroupOrOrg;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.OrganizationBean;
 import org.gcube.vomanagement.usermanagement.UserManager;
@@ -72,45 +72,6 @@ public class AssociationToGroupAndNotifyThread extends Thread {
 
 		logger.info("Association thread started to put the dataset with id = "+ datasetId + " into group with title " + groupTitle + " for user " + username);
 
-		//		if(groupTitle != null){
-		//			try{
-		//
-		//				// create the group
-		//				CkanGroup group = catalogue.createGroup(groupTitle, groupTitle, "");
-		//
-		//				if(group == null){
-		//
-		//					logger.warn("The group doesn't exist! Unable to perform such association");
-		//
-		//				}else{
-		//
-		//					logger.debug("Group exists, going to add the user " + username + " as its admin...");
-		//
-		//					// retrieve the role to be assigned according the one the user has into the organization of the dataset
-		//					RolesCkanGroupOrOrg role = RolesCkanGroupOrOrg.valueOf(catalogue.getRoleOfUserInOrganization(username, organization, catalogue.getApiKeyFromUsername(username)).toUpperCase());
-		//
-		//					if(!role.equals(RolesCkanGroupOrOrg.ADMIN))
-		//						role = RolesCkanGroupOrOrg.MEMBER; // decrease the role to member if it is not an admin
-		//
-		//					boolean assigned = catalogue.checkRoleIntoGroup(username, groupTitle, role);
-		//
-		//					if(assigned){
-		//
-		//						logger.debug("Admin/editor role was assigned for this group, going to associate the product to the group");
-		//						boolean putIntoGroup = catalogue.assignDatasetToGroup(groupTitle, datasetId, catalogue.getApiKeyFromUsername(username));
-		//						logger.info("Was product put into group? " + putIntoGroup);
-		//
-		//						if(putIntoGroup)
-		//							notifyGroupAdmins(catalogue, group.getName(), group.getTitle(), username);
-		//
-		//					}			
-		//				}
-		//
-		//			}catch(Exception e){
-		//				logger.warn("Something went wrong when tried to add the group " + groupTitle, e);
-		//			}
-		//		}
-
 		// force creation of groups if needed
 		if(groupsForceCreation != null){
 			logger.info("Groups that must be created before association are  " + groupsForceCreation);
@@ -157,7 +118,7 @@ public class AssociationToGroupAndNotifyThread extends Thread {
 			List<String> adminsEmails = new ArrayList<String>();
 
 			for(int i = 0; i < admins.size(); i++){
-				String convertedName = UtilMethods.fromCKanUsernameToUsername(admins.get(i));
+				String convertedName = CatalogueUtilMethods.fromCKanUsernameToUsername(admins.get(i));
 				admins.set(i, convertedName);
 			}
 
